@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Controller.php,v 1.15 2007/02/12 10:39:51 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Controller.php,v 1.16 2007/02/17 14:28:09 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -74,7 +74,7 @@ define('SYL_CONTROLLER_NAME', 'controller');
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Controller.php,v 1.15 2007/02/12 10:39:51 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Controller.php,v 1.16 2007/02/17 14:28:09 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_Controller
@@ -107,10 +107,26 @@ class SyL_Controller
      * @var string
      */
     var $components_file_name = 'components.xml';
+    /**
+     * ե륿ե̾
+     *
+     * @access private
+     * @var string
+     */
+    var $filter_file_name = 'filters.xml';
+    /**
+     * ե륿ե̾
+     *
+     * @access private
+     * @var string
+     */
+    var $action_file_name = 'actions.xml';
     /**
      * 顼ϥɥ᥽å̾
      * ''ξϥ顼ϥɥꤷʤ
      *
+     * SyL_ErrorǻѤƤ
+     *
      * @access private
      * @var string
      */
@@ -180,10 +196,6 @@ class SyL_Controller
         if ($this->destory_handler_method != '') {
             register_shutdown_function(array(&$this, $this->destory_handler_method));
         }
-        // 顼ϥɥ
-        if ($this->error_handler_method != '') {
-            set_error_handler(array(&$this, $this->error_handler_method));
-        }
     }
 
     /**
@@ -301,7 +313,6 @@ class SyL_Controller
     function errorStream()
     {
         static $num = 1;
-
         // ߤΥ顼٥뤫饨顼̤ɽ뤫Ƚ
         if (func_get_arg(0) & error_reporting()) {
             if ($num++ > 1) {
@@ -309,10 +320,6 @@ class SyL_Controller
                 exit;
             }
 
-            // ƥʤ˥顼ȯȲɽʤʤ뤿
-            // 顼ɽϡob_clean() ǥꥢ롣
-            echo "[SyL_error] Controller init error message: " . func_get_arg(1) . " file: " . func_get_arg(2) . " line: " . func_get_arg(3) . "\r\n";
-
             for ($i=0; $i<5; $i++) {
                 $this->error[$i] = func_get_arg($i);
             }
@@ -324,7 +331,8 @@ class SyL_Controller
             $this->raiseEvent('errorStream');
             exit;
         } else {
-            // 󥰤Ȥ
+            $error_message = "[SyL_error] Background error logging. level " . func_get_arg(0) . " message: " . func_get_arg(1) . " file: " . func_get_arg(2) . " line: " . func_get_arg(3);
+            SyL_Loggers::info($error_message);
         }
     }
 
