@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Response.php,v 1.5 2007/02/03 11:44:45 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Response.php,v 1.6 2007/02/17 14:28:09 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Response.php,v 1.5 2007/02/03 11:44:45 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Response.php,v 1.6 2007/02/17 14:28:09 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_Response
@@ -95,7 +95,7 @@ class SyL_Response
         SyL_Loggers::info("[Response] 404 Not Found - {$request_uri}");
 
         SyL_Response::setStatusHeader('404');
-        if (defined('SYL_ERROR_URL_404') && SYL_ERROR_URL_404) {
+        if (SYL_ERROR_URL_404) {
             SyL_Response::redirect(SYL_ERROR_URL_404);
         } else {
             echo "<h2>HTTP/1.0 404 Not Found</h2>";
@@ -203,16 +203,38 @@ class SyL_Response
      */
     function display(&$view)
     {
+        $data           = '';
+        $content_type   = '';
+        $content_length = false;
+        if (is_object($view)) {
+            $data           =& $view->getRender();
+            $content_type   =  $view->getContentType();
+            $content_length =  $view->isContentLength();
+        } else {
+            $data = $view;
+        }
+
+        // ƥĥפ򥻥å
+        if ($content_type) {
+            SyL_Response::setHeader('Content-Type', $content_type);
+        }
+        // ƥ̤򥻥å
+        if ($content_length) {
+            SyL_Response::setHeader('Content-Length', strlen($data));
+        }
         // إå
         $this->sendHeader();
         // ɽǡ
-        echo is_object($view) ? $view->getRender() : $view;
+        echo $data;
 
         // Хåե󥰽
         $neste = ob_get_level();
         for ($i=0; $i<$neste; $i++) {
             ob_end_flush();
         }
+
+        // 
+        $view->clearRender();
     }
 
     /**
