@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_View.php,v 1.13 2007/02/12 10:39:51 seasonstream Exp $
+ * @version   CVS: $Id: SyL_View.php,v 1.14 2007/02/17 14:28:09 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -44,7 +44,7 @@ require_once SYL_INCLUDE_DIR . '/framework/SyL_Config.php';
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_View.php,v 1.13 2007/02/12 10:39:51 seasonstream Exp $
+ * @version   CVS: $Id: SyL_View.php,v 1.14 2007/02/17 14:28:09 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_View
@@ -63,6 +63,20 @@ class SyL_View
      * @var array
      */
     var $config = array();
+    /**
+     * ƥĥ
+     * 
+     * @access protected
+     * @var string
+     */
+    var $content_type = '';
+    /**
+     * ƥ̽Ƚ
+     * 
+     * @access protected
+     * @var bool
+     */
+    var $content_length = false;
     /**
      * ɽƤΥǡ
      * 
@@ -87,6 +101,8 @@ class SyL_View
     function SyL_View(&$dm)
     {
         $this->dm =& $dm;
+        // ǥХå٥ˤꡢcontent-lengthϤ뤫Ƚ
+        $this->content_length = (SYL_DEBUG < SYL_LOG_DEBUG);
     }
 
     /**
@@ -248,15 +264,52 @@ class SyL_View
     {
     }
 
+    /**
+     * ƥĥפ򥻥å
+     * 
+     * @access public
+     * @param string ƥĥ
+     */
+    function setContentType($content_type)
+    {
+        $this->content_type = $content_type;
+    }
+
+    /**
+     * ƥĥפ
+     * 
+     * @access public
+     * @return string ƥĥ
+     */
+    function getContentType()
+    {
+        return $this->content_type;
+    }
+
+    /**
+     * ƥ̽Ƚ
+     * 
+     * @access public
+     * @param bool ƥ̽Ƚ
+     * @return bool ƥ̽Ƚ
+     */
+    function isContentLength($content_length=null)
+    {
+        if (is_bool($content_length)) {
+            $this->content_length = ($content_length === true);
+        }
+        return $this->content_length;
+    }
+
     /**
      * ɽƤ򥻥å
      * 
      * @access public
      * @param string ɽ
      */
-    function setRender($render)
+    function setRender(&$render)
     {
-        $this->render = $render;
+        $this->render =& $render;
     }
 
     /**
@@ -265,10 +318,21 @@ class SyL_View
      * @access public
      * @return string HTML
      */
-    function getRender()
+    function &getRender()
     {
         return $this->render;
     }
+
+    /**
+     * ɽƤ
+     * 
+     * @access public
+     */
+    function clearRender()
+    {
+        unset($this->render);
+        $this->render = '';
+    }
 }
 
 
