@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ViewJson.php,v 1.3 2007/02/12 10:39:51 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ViewJson.php,v 1.4 2007/02/17 14:28:09 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ViewJson.php,v 1.3 2007/02/12 10:39:51 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ViewJson.php,v 1.4 2007/02/17 14:28:09 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_ViewJson extends SyL_View
@@ -61,8 +61,9 @@ class SyL_ViewJson extends SyL_View
      */
     function render()
     {
-        // JavaScirptƥĥ
-        SyL_Response::setHeader('Content-Type', 'application/json; charset=' . SYL_ENCODE_AJAX);
+        // ƥĥפ򥻥å
+        $this->setContentType('application/json; charset=' . SYL_ENCODE_AJAX);
+
         if ($this->dm->getActionName() != '') {
             // ѥ᡼ϡJson֥Ȥ򥻥å
             if (!function_exists('json_encode')) {
@@ -70,13 +71,8 @@ class SyL_ViewJson extends SyL_View
             }
             $values     =& $this->getActionValues();
             $javascript = json_encode($values);
-            $javascript = mb_convert_encoding($javascript, SYL_ENCODE_AJAX, SYL_ENCODE_INTERNAL);
-
             // JavaScirpt
             $this->setRender($javascript);
-        } else {
-            // Ϥʤ
-            $this->setRender('');
         }
     }
 }
