@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ViewLayoutDefault.php,v 1.2 2007/02/12 10:39:51 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ViewLayoutDefault.php,v 1.3 2007/02/17 14:28:09 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ViewLayoutDefault.php,v 1.2 2007/02/12 10:39:51 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ViewLayoutDefault.php,v 1.3 2007/02/17 14:28:09 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_ViewLayoutDefault extends SyL_View
@@ -61,6 +61,9 @@ class SyL_ViewLayoutDefault extends SyL_View
      */
     function render()
     {
+        // ƥĥפ򥻥å
+        $this->setContentType('text/html; charset=' . SYL_ENCODE_INTERNAL);
+
         // 󤫤Υѥ᡼
         $values =& $this->getActionValues();
         foreach (array_keys($values) as $key) {
@@ -82,8 +85,7 @@ class SyL_ViewLayoutDefault extends SyL_View
         // ɽƤ򥻥å
         ob_start();
         include_once $template_file;
-        $this->setRender(ob_get_contents());
-        ob_end_clean();
+        $this->setRender(ob_get_clean());
     }
 }
 
