@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ViewLayoutSmarty.php,v 1.2 2007/02/12 10:39:51 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ViewLayoutSmarty.php,v 1.3 2007/02/17 14:28:09 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -44,7 +44,7 @@ require_once SYL_SMARTY_DIR . 'Smarty.class.php';
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ViewLayoutSmarty.php,v 1.2 2007/02/12 10:39:51 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ViewLayoutSmarty.php,v 1.3 2007/02/17 14:28:09 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_ViewLayoutSmarty extends SyL_View
@@ -78,6 +78,9 @@ class SyL_ViewLayoutSmarty extends SyL_View
      */
     function render()
     {
+        // ƥĥפ򥻥å
+        $this->setContentType('text/html; charset=' . SYL_ENCODE_INTERNAL);
+
         // 󤫤Υѥ᡼
         $values =& $this->getActionValues();
         foreach (array_keys($values) as $key) {
