@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Pager.php,v 1.4 2007/01/21 08:13:15 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Pager.php,v 1.5 2007/02/17 14:28:09 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Pager.php,v 1.4 2007/01/21 08:13:15 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Pager.php,v 1.5 2007/02/17 14:28:09 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_Pager
@@ -72,7 +72,6 @@ class SyL_Pager
      * @var int
      */
     var $page = 1;
-
     /**
      * ڡURL
      * 
@@ -80,7 +79,6 @@ class SyL_Pager
      * @var string
      */
     var $url = '';
-
     /**
      * ڡ衢ѥ᡼̾ʥڡѥ᡼
      * 
@@ -114,10 +112,7 @@ class SyL_Pager
      */
     function setCount($num)
     {
-        if (!is_numeric($num) || ($num < 0)) {
-            $num = 0;
-        }
-        $this->num = $num;
+        $this->num = (!is_numeric($num) || ($num < 0)) ? 0 : $num;
     }
 
     /**
@@ -139,10 +134,7 @@ class SyL_Pager
      */
     function setCountAll($sum)
     {
-        if (!is_numeric($sum) || ($sum < 0)) {
-            $sum = 0;
-        }
-        $this->sum = $sum;
+        $this->sum = (!is_numeric($sum) || ($sum < 0)) ? 0 : $sum;
     }
 
     /**
@@ -165,10 +157,7 @@ class SyL_Pager
      */
     function setPage($current_page)
     {
-        if (!is_numeric( $current_page ) || ($current_page < 1)) {
-            $current_page = 1;
-        }
-        $this->current_page = $current_page;
+        $this->current_page = (!is_numeric($current_page) || ($current_page < 1)) ? 1 : $current_page;
     }
 
     /**
@@ -177,7 +166,7 @@ class SyL_Pager
      * @access public
      * @return int ߥڡ
      */
-    function getPage()
+    function getCurrentPage()
     {
         // 쥳ɿ0ΤȤϥڡ0
         if ($this->sum <= 0) {
@@ -221,20 +210,47 @@ class SyL_Pager
      */
     function setEtcParameter($etc_parameters)
     {
-        $this->etc_parameters = $this->getAmp( $etc_parameters );
+        $this->etc_parameters = $this->getAmp($etc_parameters);
     }
 
     /**
-     * ǡκǽΥ쥳ɤ
+     * ǡκǽΥ쥳ɤ긡ѡ
      * ǽΥ쥳ɤ0Ȥ롣
      *
      * @access public
      * @return int ǡκǽΥ쥳
      */
+    function getStartOffset()
+    {
+        $offset = $this->getCount() * ($this->getCurrentPage() - 1);
+        return ($offset < 0) ? 0 : $offset;
+    }
+
+    /**
+     * ǡоݤκǽΥ쥳ɤ
+     *
+     * @access public
+     * @return int ǡоݤκǽΥ쥳
+     */
     function getStartRecord()
     {
-        $offset = $this->getCount() * ($this->getPage() - 1);
-        return (($offset < 0) ? 0 : $offset);
+        $offset = $this->getCount() * ($this->getCurrentPage() - 1);
+        return ($offset < 0) ? 0 : $offset + 1;
+    }
+
+    /**
+     * ǡоݤκǸΥ쥳ɤ
+     *
+     * @access public
+     * @return int ǡоݤκǸΥ쥳
+     */
+    function getEndRecord()
+    {
+        if ($this->getCurrentPage() >= $this->getTotalPage()) {
+            return $this->getCountAll();
+        } else {
+            return $this->getCount() * $this->getCurrentPage();
+        }
     }
 
     /**
@@ -260,7 +276,7 @@ class SyL_Pager
     function getNextLink($active_link_message, $noactive_link_message='')
     {
         // 쥳ɿ0ڡʤޤϸMAXڡܾ
-        if (($this->sum <= 0) || ($this->getTotalPage() == 1) || ($this->current_page >= $this->getTotalPage())) {
+        if (($this->sum <= 0) || ($this->getTotalPage() == 1) || ($this->current_page == $this->getTotalPage())) {
             return (($noactive_link_message == '') ? $active_link_message : $noactive_link_message);
         // ڡʾΥڡꤵ줿1ڡܥ󥯤
         } else if ($this->current_page > $this->getTotalPage()) {
