@@ -18,9 +18,9 @@ class {SYL_CLASS}
      *
      * @access public
      * @param object ꥯȥ֥
-     * @param object ݡͥȥ᥽åɥ֥
+     * @param object ǡ֥
      */
-    function execute(&$request, &$cm)
+    function execute(&$request, &$dm)
     {
     }
 
